@@ -1,9 +1,10 @@
 from .utils import replace_names
-from .nn import explain_class
+from .nn import entropy, psi
 from .metrics import test_explanation, concept_consistency, formula_consistency, complexity
 
 __all__ = [
-    'explain_class',
+    'entropy',
+    'psi',
     'test_explanation',
     'replace_names',
     'concept_consistency',
